@@ -18,6 +18,10 @@ test_that("fit", {
   expect_equal_to_reference(fit.i.sex, file = "rds/fit.i.sex.rds")
   expect_equal_to_reference(capture.output(fit.i), file = "rds/print.fit.i.rds")
   expect_equal_to_reference(capture.output(fit.i.sex), file = "rds/print.fit.sex.rds")
+
+  ## errors
+  x <- incidence(c(1, 0, 0, 0), interval = 7)
+  expect_error(fit(x), "Only 1 date with non-zero incidence. Cannot fit model to 1 data point.")
 })
 
 test_that("fit_optim_split", {
@@ -31,8 +35,10 @@ test_that("fit_optim_split", {
   i <- incidence(dat, 5L)
   i.sex <- incidence(dat, 5L, groups = sex)
 
-  expect_equal_to_reference(fit_optim_split(i), file = "rds/o.fit.i.rds")
-  expect_equal_to_reference(fit_optim_split(i.sex), file = "rds/o.fit.i.sex.rds")
+  expect_equal_to_reference(fit_optim_split(i, plot = FALSE),
+                            file = "rds/o.fit.i.rds")
+  expect_equal_to_reference(fit_optim_split(i.sex, plot = FALSE),
+                            file = "rds/o.fit.i.sex.rds")
 
   ## errors
   expect_error(fit_optim_split(i, window = -1),
